#
# spec file for package python-cli-helpers
#
# Copyright (c) 2023 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%{?!python_module:%define python_module() python-%{**} python3-%{**}}
%bcond_without python2
Name:           python-cli-helpers
Version:        2.3.0
Release:        1.5
Summary:        Helpers for building command-line apps
License:        BSD-3-Clause
URL:            https://github.com/dbcli/cli_helpers
Source:         https://files.pythonhosted.org/packages/source/c/cli_helpers/cli_helpers-%{version}.tar.gz
BuildRequires:  %{python_module setuptools}
BuildRequires:  fdupes
BuildRequires:  python-rpm-macros
Requires:       python-Pygments >= 2.4
Requires:       python-configobj >= 5.0.5
Requires:       python-tabulate >= 0.8.2
Requires:       python-terminaltables >= 3.0.0
Requires:       python-wcwidth
BuildArch:      noarch
# SECTION test requirements
# Package dependencies
BuildRequires:  %{python_module Pygments >= 2.4}
BuildRequires:  %{python_module configobj >= 5.0.5}
BuildRequires:  %{python_module pytest >= 3.0.7}
BuildRequires:  %{python_module tabulate >= 0.8.2}
BuildRequires:  %{python_module terminaltables >= 3.0.0}
BuildRequires:  %{python_module wcwidth}
%if %{with python2}
BuildRequires:  python2-backports.csv >= 1.0.0
%endif
# /SECTION
%ifpython2
Requires:       python2-backports.csv >= 1.0.0
%endif
%python_subpackages

%description
CLI Helpers is a Python package for performing common tasks when
building command-line apps. It's a helper library for command-line interfaces.

Libraries like Click <http://click.pocoo.org/5/> and Python Prompt
Toolkit <https://python-prompt-toolkit.readthedocs.io/en/latest/> are
tools that help to create quality apps. CLI Helpers complements these
libraries by wrapping up common tasks in interfaces.

CLI Helpers is not focused on applications' design patterns or
frameworks -- it can be used it on its own or in combination with
other libraries.

%prep
%setup -q -n cli_helpers-%{version}

%build
%python_build

%install
%python_install
%python_expand %fdupes %{buildroot}%{$python_sitelib}

%check
%pytest

%files %{python_files}
%license LICENSE
%doc README.rst AUTHORS CHANGELOG docs
%{python_sitelib}/*

%changelog
* Wed Jan  4 2023 Dirk Müller <dmueller@suse.com>
- update to 2.3.0:
  * don't escape newlines, etc. in ascii tables, and add ascii_escaped table
    format
* Tue Mar  8 2022 pgajdos@suse.com
- version update to 2.2.1
  Version 2.2.1
  - ------------
  * Fix pygments tokens passed as strings
  Version 2.2.0
  - ------------
  * Remove dependency on terminaltables
  * Add psql_unicode table format
  * Add minimal table format
  * Fix pip2 installing py3-only versions
  * Format unprintable bytes (eg 0x00, 0x01) as hex
* Wed Jun 24 2020 Steve Kowalik <steven.kowalik@suse.com>
- Update to 2.0.1:
  * Fix newline escaping in plain-text formatters (ascii, double, github)
  * Use built-in unittest.mock instead of mock.
  * Remove Python 2.7 and 3.5.
  * Style config for missing value.
* Thu Apr 23 2020 Tomáš Chvátal <tchvatal@suse.com>
- Do not pull python2 deps without python2
* Mon Jun 17 2019 Tomáš Chvátal <tchvatal@suse.com>
- Update to 1.2.1:
  * Work with new pygments
- Remove merged patch:
  * pygments.patch
* Tue May 28 2019 Tomáš Chvátal <tchvatal@suse.com>
- Update to 1.2.0:
  * Run tests on Python 3.7.
  * Use twine check during packaging tests.
  * Rename old tsv format to csv-tab (because it add quotes), introduce new tsv output adapter.
  * Truncate long fields for tabular display.
  * Return the supported table formats as unicode.
  * Override tab with 4 spaces for terminal tables.
- Add patch to fix build with new pygments:
  * pygments.patch
* Wed Feb  6 2019 Jan Engelhardt <jengelh@inai.de>
- Trim bias and excess markup from description.
* Sun Feb  3 2019 John Vandenberg <jayvdb@gmail.com>
- Initial spec for cli-helpers v1.1.0
